sqlobject.postgres.pgconnection module — SQLObject 3.9.1 documentation

# sqlobject.postgres.pgconnection module

class `sqlobject.postgres.pgconnection.` `ErrorMessage`(e, append_msg='')

  Bases: `str`

`sqlobject.postgres.pgconnection.` `OdbcBinaryConverter`(value, db)

`sqlobject.postgres.pgconnection.` `PostgresBinaryConverter`(value, db)

class `sqlobject.postgres.pgconnection.` `PostgresConnection`(dsn=None, host=None, port=None, db=None, user=None, password=None, **kw)

  Bases: `sqlobject.dbconnection.DBAPI`

  `addColumn`(tableName, column)
  `columnsFromSchema`(tableName, soClass)
  `createColumn`(soClass, col)
  `createEmptyDatabase`()

    Create an empty database.

  `createIDColumn`(soClass)
  `createIndexSQL`(soClass, index)
  `createReferenceConstraint`(soClass, col)
  `dbName` = 'postgres'
  `defaultFromSchema`(colClass, defaultstr)

    If the default can be converted to a python constant, convert it. Otherwise return is as a sqlbuilder constant.

  `delColumn`(sqlmeta, column)
  `dropDatabase`()
  `dropTable`(tableName, cascade=False)
  `guessClass`(t)
  `joinSQLType`(join)
  `listDatabases`()
  `listTables`()
  `makeConnection`()
  `odbc_keywords` = ('Server', 'Port', 'UID', 'Password', 'Database')
  `schemes` = ['postgres', 'postgresql']
  `supportTransactions` = True
  `tableExists`(tableName)

`sqlobject.postgres.pgconnection.` `PsycoBinaryConverter`(value, db)

`sqlobject.postgres.pgconnection.` `escape_bytea`(value)